@@ -76,10 +76,23 @@ class Overview(object):
         self.get_widget("reports_tab").add(self.reports)
 
         self.range_combo = gtk.combo_box_new_text()
-        self.range_combo.append_text(_("Week"))
-        self.range_combo.append_text(_("Month"))
-        self.range_combo.append_text(_("Date Range"))
-        self.range_combo.set_active(0)
+        self.ranges = {}
+        
+        def add_range_option(key, label):
+            """
+            Insert a new item in the range combo and map its index into the
+            ranges dictionary.
+            """
+            self.range_combo.append_text(label)
+            index = self.range_combo.get_model().iter_n_children(None)-1
+            self.ranges[key] = index
+
+        add_range_option("day", _("Day"))
+        add_range_option("week", _("Week"))
+        add_range_option("month", _("Month"))
+        add_range_option("custom", _("Date Range"))
+        
+        self.range_combo.set_active(self.ranges["week"])
         self.range_combo.connect("changed", self.on_range_combo_changed)
 
 
@@ -200,9 +213,19 @@ class Overview(object):
     def after_activity_update(self, widget):
         self.search()
 
+    def on_search_icon_press(self, widget, position, data):
+        if position == gtk.ENTRY_ICON_SECONDARY:
+            widget.set_text('')
+
+        self.search()
+
     def on_search_activate(self, widget):
         self.search()
 
+    def on_search_changed(self, widget):
+        has_text = len(widget.get_text()) > 0
+        widget.set_icon_sensitive(gtk.ENTRY_ICON_SECONDARY, has_text)
+
     def on_report_button_clicked(self, widget):
         def on_report_chosen(widget, format, path):
             self.report_chooser = None
@@ -234,16 +257,21 @@ class Overview(object):
         self.get_widget("preset_range").hide()
         self.get_widget("range_box").hide()
 
-        if idx == 2: # date range
+        if idx == self.ranges["custom"]:
             self.get_widget("range_box").show()
         else:
-            if idx == 0: # week
+            if idx == self.ranges["day"]:
+                self.start_date = self.view_date
+                self.end_date = self.start_date + dt.timedelta(0)
+                self.get_widget("preset_range").show()
+
+            elif idx == self.ranges["week"]:
                 self.start_date = self.view_date - dt.timedelta(self.view_date.weekday() + 1)
                 self.start_date = self.start_date + dt.timedelta(stuff.locale_first_weekday())
                 self.end_date = self.start_date + dt.timedelta(6)
                 self.get_widget("preset_range").show()
 
-            elif idx == 1: #month
+            elif idx == self.ranges["month"]:
                 self.start_date = self.view_date - dt.timedelta(self.view_date.day - 1) #set to beginning of month
                 first_weekday, days_in_month = calendar.monthrange(self.view_date.year, self.view_date.month)
                 self.end_date = self.start_date + dt.timedelta(days_in_month - 1)
@@ -258,22 +286,25 @@ class Overview(object):
 
 
     def on_start_date_entered(self, input):
-        self.start_date = input.get_date().date()
+        self.start_date = input.get_date()
         self.view_date = self.start_date
         self.search()
 
     def on_end_date_entered(self, input):
-        self.end_date = input.get_date().date()
+        self.end_date = input.get_date()
         self.search()
 
     def _chosen_range(self):
         return self.range_combo.get_active()
 
     def on_prev_clicked(self, button):
-        if self._chosen_range() == 0:  # week
+        if self._chosen_range() == self.ranges["day"]:
+            self.start_date -= dt.timedelta(1)
+            self.end_date -= dt.timedelta(1)
+        elif self._chosen_range() == self.ranges["week"]:
             self.start_date -= dt.timedelta(7)
             self.end_date -= dt.timedelta(7)
-        elif self._chosen_range() == 1: # month
+        elif self._chosen_range() == self.ranges["month"]:
             self.end_date = self.start_date - dt.timedelta(1)
             first_weekday, days_in_month = calendar.monthrange(self.end_date.year, self.end_date.month)
             self.start_date = self.end_date - dt.timedelta(days_in_month - 1)
@@ -282,10 +313,13 @@ class Overview(object):
         self.search()
 
     def on_next_clicked(self, button):
-        if self._chosen_range() == 0:  # week
+        if self._chosen_range() == self.ranges["day"]:
+            self.start_date += dt.timedelta(1)
+            self.end_date += dt.timedelta(1)
+        elif self._chosen_range() == self.ranges["week"]:
             self.start_date += dt.timedelta(7)
             self.end_date += dt.timedelta(7)
-        elif self._chosen_range() == 1: # month
+        elif self._chosen_range() == self.ranges["month"]:
             self.start_date = self.end_date + dt.timedelta(1)
             first_weekday, days_in_month = calendar.monthrange(self.start_date.year, self.start_date.month)
             self.end_date = self.start_date + dt.timedelta(days_in_month - 1)
@@ -297,12 +331,16 @@ class Overview(object):
     def on_home_clicked(self, button):
         self.view_date = (dt.datetime.today() - dt.timedelta(hours = self.day_start.hour,
                                                         minutes = self.day_start.minute)).date()
-        if self._chosen_range() == 0: # week
+        if self._chosen_range() == self.ranges["day"]:
+            self.start_date = self.view_date
+            self.end_date = self.start_date + dt.timedelta(0)
+
+        elif self._chosen_range() == self.ranges["week"]:
             self.start_date = self.view_date - dt.timedelta(self.view_date.weekday() + 1)
             self.start_date = self.start_date + dt.timedelta(stuff.locale_first_weekday())
             self.end_date = self.start_date + dt.timedelta(6)
 
-        elif self._chosen_range() == 1: # month
+        elif self._chosen_range() == self.ranges["month"]:
             self.start_date = self.view_date - dt.timedelta(self.view_date.day - 1) #set to beginning of month
             first_weekday, days_in_month = calendar.monthrange(self.view_date.year, self.view_date.month)
             self.end_date = self.start_date + dt.timedelta(days_in_month - 1)
@@ -319,6 +357,7 @@ class Overview(object):
         elif pagenum == 1:
             self.get_widget('remove').set_sensitive(False)
             self.get_widget('edit').set_sensitive(False)
+            self.reports.do_charts()
 
 
     def on_add_clicked(self, button):
