@@ -22,6 +22,7 @@ import calendar
 import time
 import webbrowser
 from itertools import groupby
+import locale
 
 from gettext import ngettext
 
@@ -45,7 +46,7 @@ class TotalsBox(gtk.VBox):
         self.start_date, self.end_date = None, None
 
         #graphs
-        x_offset = 100 # align all graphs to the left edge
+        x_offset = 0.4 # align all graphs to the left edge
 
 
         self.category_chart = charting.Chart(max_bar_width = 20,
@@ -88,6 +89,7 @@ class TotalsBox(gtk.VBox):
             self.category_chart.selected_keys.append(key)
             self.selected_categories.append(key)
 
+        self.calculate_totals()
         self.do_charts()
 
     def on_activity_clicked(self, widget, key):
@@ -97,6 +99,7 @@ class TotalsBox(gtk.VBox):
         else:
             self.activity_chart.selected_keys.append(key)
             self.selected_activities.append(key)
+        self.calculate_totals()
         self.do_charts()
 
     def on_tag_clicked(self, widget, key):
@@ -106,17 +109,15 @@ class TotalsBox(gtk.VBox):
         else:
             self.tag_chart.selected_keys.append(key)
             self.selected_tags.append(key)
+        self.calculate_totals()
         self.do_charts()
 
 
-    def on_reports_box_expose_event(self, box, someth):
-        self.do_charts()
-
     def search(self, start_date, end_date, facts):
         self.facts = facts
         self.category_sums, self.activity_sums, self.tag_sums = [], [], []
         self.selected_categories, self.selected_activities, self.selected_tags = [], [], []
-        self.category_chart.bars_selected, self.activity_chart.bars_selected, self.tag_chart.bars_selected = [], [], []
+        self.category_chart.selected_keys, self.activity_chart.selected_keys, self.tag_chart.selected_keys = [], [], []
 
         self.start_date = start_date
         self.end_date = end_date
@@ -129,6 +130,7 @@ class TotalsBox(gtk.VBox):
             self.get_widget("no_data_label").hide()
             self.get_widget("charts").show()
             self.get_widget("total_hours").show()
+            self.calculate_totals()
             self.do_charts()
         else:
             self.get_widget("no_data_label").show()
@@ -136,7 +138,7 @@ class TotalsBox(gtk.VBox):
             self.get_widget("total_hours").hide()
 
 
-    def do_charts(self):
+    def calculate_totals(self):
         if not self.facts:
             return
 
@@ -144,7 +146,7 @@ class TotalsBox(gtk.VBox):
         facts = copy.deepcopy(self.facts)
 
         total_hours = sum([stuff.duration_minutes(fact["delta"]) for fact in facts])
-        total_label = _("%s hours tracked total") % ("%.1f" % (total_hours / 60.0))
+        total_label = _("%s hours tracked total") % locale.format("%.1f", total_hours / 60.0)
         self.get_widget("total_hours").set_text(total_label)
 
 
@@ -201,24 +203,25 @@ class TotalsBox(gtk.VBox):
             self.tag_sums = zip(*tag_sums)
 
 
+    def do_charts(self):
         self.get_widget("totals_by_category").set_size_request(10,10)
         if self.category_sums:
-            self.get_widget("totals_by_category").set_size_request(280, len(self.category_sums[0]) * 20)
+            self.get_widget("totals_by_category").set_size_request(-1, len(self.category_sums[0]) * 20)
             self.category_chart.plot(*self.category_sums)
         else:
-            self.get_widget("totals_by_category").set_size_request(280, 10)
+            self.get_widget("totals_by_category").set_size_request(-1, 10)
             self.category_chart.plot([],[])
 
         self.get_widget("totals_by_activity").set_size_request(10,10)
-        self.get_widget("totals_by_activity").set_size_request(280, len(self.activity_sums[0]) * 20)
+        self.get_widget("totals_by_activity").set_size_request(-1, len(self.activity_sums[0]) * 20)
         self.activity_chart.plot(*self.activity_sums)
 
         self.get_widget("totals_by_tag").set_size_request(10,10)
         if self.tag_sums:
-            self.get_widget("totals_by_tag").set_size_request(280, len(self.tag_sums[0]) * 20)
+            self.get_widget("totals_by_tag").set_size_request(-1, len(self.tag_sums[0]) * 20)
             self.tag_chart.plot(*self.tag_sums)
         else:
-            self.get_widget("totals_by_tag").set_size_request(280, 10)
+            self.get_widget("totals_by_tag").set_size_request(-1, 10)
             self.tag_chart.plot([],[])
 
 
